#
# spec file for package openttd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2007-2012 The OpenTTD developers
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define about OpenTTD is a reimplementation of the Microprose game "Transport Tycoon Deluxe" with lots of new features and enhancements. To play the game, you need either the original proprietary data set from the game, or install the recommend subpackages OpenGFX, OpenSFX and OpenMSX for an alternate, free set of graphics, sounds and music, respectively.
Name:           openttd
Version:        1.8.0
Release:        lp150.1.1
Summary:        A clone of Chris Sawyer's Transport Tycoon Deluxe
License:        GPL-2.0-only
Group:          Amusements/Games/Strategy/Other
URL:            http://www.openttd.org
Source:         http://binaries.openttd.org/releases/%{version}/%{name}-%{version}-source.tar.xz
# PATCH-FEATURE-UPSTREAM https://bugs.openttd.org/task/6490
Source2:        openttd.appdata.xml
BuildRequires:  SDL-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++ > 3.3
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-io)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(zlib)
Requires:       %{name}-data = %{version}-%{release}
Conflicts:      %{name}-dedicated
Provides:       %{name}-gui = %{version}
%if 0%{?mdkversion}
BuildRequires:  liblzma-devel
BuildRequires:  liblzo-devel
%else
BuildRequires:  lzo-devel
BuildRequires:  pkgconfig(liblzma)
%endif
%if 0%{?suse_version} || 0%{?mdkversion}
BuildRequires:  pkgconfig(freetype2)
%else
BuildRequires:  freetype-devel
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libtimidity)
BuildRequires:  pkgconfig(libxdg-basedir)
%else
BuildRequires:  desktop-file-utils
BuildRequires:  grfcodec
%endif
%if 0%{?suse_version} || 0%{?mdkversion}
Recommends:     adobe-sourcehansans-fonts
Recommends:     openttd-openmsx
Recommends:     openttd-opensfx
%endif

%description
%{about}

Use package %{name}-dedicated for systems without SDL.

%package dedicated
Summary:        OpenTTD Dedicated Server binary (without SDL)
Group:          Amusements/Games/Strategy/Other
Requires:       %{name}-data = %{version}-%{release}
Conflicts:      %{name}

%description dedicated
%{about}

This package provides the binary %{name}-dedicated without dependency of SDL.

%package data
Summary:        OpenTTD data
Group:          Amusements/Games/Strategy/Other
%if 0%{?suse_version} || 0%{?fedora} || 0%{?mdkversion} || 0%{?rhel_version} >= 600 || 0%{?centos_version} >= 600
BuildArch:      noarch
%endif
%if 0%{?suse_version} || 0%{?mdkversion}
Recommends:     openttd-opengfx >= 0.5.2
%endif

%description data
%{about}

This package provides the data files needed by %{name} or %{name}-dedicated.

%prep
%setup -q

# Remove build time references so build-compare can do its work
sed -i "s/__DATE__/\"openSUSE\"/" src/rev.cpp.in
sed -i "s/__TIME__/\"BuildService\"/" src/rev.cpp.in
sed -i "s/!!DATE!!/openSUSE Build Service/" src/rev.cpp.in

%build
# first, we build the dedicated binary and copy it to dedicated/
CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" \
CFLAGS_BUILD="%{optflags}" CXXFLAGS_BUILD="%{optflags}" \
./configure \
        --disable-strip \
        --prefix-dir="%{_prefix}" \
        --binary-dir="bin" \
        --data-dir="share/%{name}" \
        --enable-dedicated
make %{?_smp_mflags} bundle BUNDLE_DIR="dedicated" VERBOSE=1

make %{?_smp_mflags} distclean
# then, we build the common gui version which we install the usual way
CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" \
CFLAGS_BUILD="%{optflags}" CXXFLAGS_BUILD="%{optflags}" \
./configure \
        --disable-strip \
        --prefix-dir="%{_prefix}" \
        --binary-name="%{name}" \
        --binary-dir="bin" \
        --data-dir="share/%{name}" \
        --doc-dir="share/doc/%{name}" \
        --menu-name="OpenTTD" \
        --menu-group="Game;StrategyGame;"

make %{?_smp_mflags} VERBOSE=1

%install
# install the dedicated server
install -D -m0755 dedicated/openttd %{buildroot}%{_bindir}/%{name}-dedicated
install -D -m0644 dedicated/man/openttd.6.gz %{buildroot}%{_mandir}/man6/%{name}-dedicated.6.gz

# install the game
make install INSTALL_DIR=%{buildroot} VERBOSE=1

mkdir -p %{buildroot}%{_datadir}/appdata
install -D -m0644 %{SOURCE2} %{buildroot}%{_datadir}/appdata/openttd.appdata.xml

%fdupes %{buildroot}%{_datadir}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%endif

%post dedicated
rm -f %{_bindir}/%{name}
ln -s %{name}-dedicated %{_bindir}/%{name}

%preun dedicated
if [ "$1" -eq 0 ] ; then
    rm -f %{_bindir}/%{name}
fi

%if 0%{?suse_version} < 1500
%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/openttd.appdata.xml
%{_datadir}/icons/hicolor
%{_datadir}/pixmaps/%{name}.32.xpm
%{_mandir}/man6/%{name}.6%{?ext_man}

%files dedicated
%{_bindir}/%{name}-dedicated
%{_mandir}/man6/%{name}-dedicated.6%{?ext_man}

%files data
%{_datadir}/doc/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/lang
%{_datadir}/%{name}/baseset
%{_datadir}/%{name}/scripts
%{_datadir}/%{name}/ai
%{_datadir}/%{name}/game

%changelog
* Mon Apr  2 2018 mimi.vx@gmail.com
- update to new release 1.8.0
  * Feature:
  - [GFX] Climate-specific Action5 extra airport sprites
  - Draw vertical separators at tile distance in the train depot GUI
  - [Build] Project file generator for kdevelop 4/5
  - Add option to close windows with right click
  - Vehicle Group Info: Add profits and occupancy display to group vehicle list
  - Display aircraft type in vehicle preview/purchase/detail windows
  * Change:
  - [NewGRF] Various performance improvements to resolving VA2
  - [NewGRF] Increase maximum allowed vehicle sprite size to reduce
    clipping of ships
  - Check companies for bankruptcy before subtracting reoccuring monthly costs
  - [GFX] Replace the office building sprite on various toyland airports
    with a better fitting sprite
  - [GFX] The switch-toolbar icon contained pixels from the fire cycle.
    Replace the whole icon with a new version
  - Reword texts in industry view, when stockpiling is used
  - Remove the gap between windows when positioning them after opening
  - [Build] Preserve PKG_CONFIG_PATH and PKG_CONFIG_LIBDIR environment
    variables in config.cache file
  - Do not cancel headquarter construction and engine-preview-query
    when shift-clicking
  - Parse extmidi command string for parameters to pass on
  - Draw images in centre of buttons
  * Fix:
  - Store the map variety setting in the savegame like the other mapgen
    settings, so restarting maps considers it
  - Hair selection was missing one option
  - Avoid tile operations outside map border when building lock
  - Catenary sprites got mixed up for depots
  - Make automatic window-positioning RTL-aware
  - Automatic window-positioning now uses GUI-scale/style dependent
    sizes/distances instead of fixed pixel values
  - [NewGRF] While executing random triggers, var 5F should include
    the new triggers
  - [NewGRF] Reset used random triggers only after all A123 chains have
    been resolved, so that all RA2 in all chains can test the shared triggers
  - [NewGRF] Industry random triggers are stored per tile, even when
    randomising the shared random bits of the parent industry
  - [NPF] Reserved track bits were not accounted for when trying to find
    any safe position
  - Do not modify argv[0]
  - Do not search directories when opening ini files as we already have
    their full path
  - Road tunnel/bridge heads have no trackbits wrt. catenary drawing
* Tue Dec 26 2017 vcizek@suse.com
- update to new release 1.7.2
  * Change: When train depots have a horizontal scrollbar, allow
    scrolling 1 tile beyond the longest train, so you can actually
    attach a wagon at the end
  * Fixes:
  - When moving wagons in the depot, the drag highlight did not
    exactly match the length of the dragged wagon chain (r27936)
  - Forest, candyfloss forest and battery farm skipped the first
    animation frame
  - Glyphs in range U+0020 to U+00FF may only be defined in
    orig_extra.grf, not in openttd.grf
  - 'unban' console command was not handling IPv6 adresses properly
  - Keep the 'link' between industry chain and smallmap windows
    whenever possible
  - When the last vehicle is removed from a shared orders group,
    hide the 'Stop sharing' button in the vehicle orders window
  - Tooltip of 'increase service interval' said 'decrease'
  - Console command parser passed invalid strings to the debug
    output, if command lines had many parameters
* Sat Aug  5 2017 jengelh@inai.de
- Update to new maintenance release 1.7.1
  * Add missing game script event for ships arriving at a station
  * Avoid an infinite loop in pathfinder when checking safe
    waiting position from a waypoint
  * YAPF: Consider depot as destination before reversing path and
    applying penalty
  * Don't consider locks or ship depots as clear water when
    placing industries
  * Resolve a failure to load LZO compressed savegames sometimes
* Sun Apr  2 2017 mimi.vx@gmail.com
- update to version 1.7.0
  * Waypoint area is now limited to the max station spread while
    dragging.
  * Rearranged GUI for the vehicle autoreplace feature.
  * Realistic acceleration is now enabled by default for trains
    and road vehicles.
- drop gcc-version-detection.patch - upstreamed
* Sat Jul 16 2016 mailaender@opensuse.org
- Update to version 1.6.1 (see changelog.txt)
- Drop openttd-gcc5.patch as it is not required anymore.
- Add gcc-version-detection.patch in collaboration with upstream.
- Add a man page for the dedicated server binary.
- Remove unnecessary desktop category macros.
- Use standard post macros for icons and starters.
- Eliminate duplicate files using fdupes.
* Thu Jun 16 2016 dimstar@opensuse.org
- Update openttd-gcc5.patch: Have gcc6 use the same flags as gcc5.
* Thu Apr  7 2016 bwiedemann@suse.com
- Fix build-compare
* Sat Dec  5 2015 mailaender@opensuse.org
- maintenance update 1.5.3
  * fixes a long standing desync issue with railtypes
* Thu Oct 15 2015 tchvatal@suse.com
- Version bump to 1.5.2:
  * For details see changelog.txt
* Wed Sep 30 2015 lnussel@suse.de
- build with proper optflags
* Fri Jun 19 2015 dimstar@opensuse.org
- Add openttd-gcc5.patch: Fix build with gcc 5.
* Sat Jun  6 2015 mailaender@opensuse.org
- update to version 1.5.1 (check changelog.txt)
* Sun Apr 26 2015 mailaender@opensuse.org
- Removed openttd-freetype-2.5.4.patch (included by upstream)
- Updated to version 1.5.0
  * higher mountains
  * better UI for high resolution screens
  * much more rural intro screen.
- Recommend adobe-sourcehansans-fonts as backfall when there is no
  sprite font (yet). Workaround https://bugs.openttd.org/task/6226
* Mon Dec 22 2014 dimstar@opensuse.org
- Add openttd-freetype-2.5.4.patch: Fix build with freetype 2.5.4.
- Move the man page to the binary, where it belongs (and drop
  the rpmlintrc-, which is now no longer valid).
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in post scripts
* Sun Oct 26 2014 mailaender@opensuse.org
- update to 1.4.4 (check changelog.txt)
* Sun Sep 28 2014 mailaender@opensuse.org
- update to 1.4.3 (bug fix release)
- added missing build requires:
  * libxdg-basedir
  * libtimidity
  * grfcodec
- avoid redundancy in %%description
* Sat Jun 14 2014 mailaender@opensuse.org
- update to 1.4.1 (regular bug fix release)
- use LZMA compressed source
* Fri Apr  4 2014 adrian@suse.de
- update to 1.4.0
  (check changelog.txt)
* Tue Dec 10 2013 suse@ammler.ch
- update to 1.3.3 (security bugfix)
  - many bugfixes including:
    Fix: Aircraft crashing near the map's border due to a lack of airports
    could trigger a crash [CVE-2013-6411] [FS#5820] (bnc#853041)
* Mon Sep 30 2013 suse@ammler.ch
- update to 1.3.2 (bugfix release)
* Sun Jun  2 2013 coder.tux@gmail.com
- update to 1.3.1
* Tue Apr  2 2013 suse@ammler.ch
- update to 1.3.0
  (check changelog.txt)
* Sun Feb 17 2013 suse@ammler.ch
- update to 1.3.0-beta2
  (check changelog.txt)
* Fri Nov  2 2012 suse@ammler.ch
- update to 1.2.3 (bugfix release)
* Thu Aug 16 2012 suse@ammler.ch
- update to 1.2.2
  - many bugfixes including:
    Fix: In some cases ships could be covered with land [FS#5254]
    (CVE-2012-3436, bnc#775023)
* Thu May 31 2012 suse@ammler.ch
- update to 1.2.1
  - many minor bugfixes (see changelog.txt)
* Wed May  9 2012 suse@ammler.ch
- remove BuildRequires hicolor-icon-them (build on SLE_10)
* Fri May  4 2012 suse@ammler.ch
- remove __DATE__ and __TIME__ reference for build-compare
- disable strip so we get debug rpms (also for stable releases)
* Mon Apr 16 2012 suse@ammler.ch
- update to 1.2.0
  * too many changes to list here, please see changelog.txt
    (files data/* moved to baseset/, no gm/ anymore)
* Mon Apr  9 2012 suse@ammler.ch
- remove update-alternatives again (bnc#749128)
- symlink openttd to openttd-dedicated
* Mon Apr  2 2012 suse@ammler.ch
- update to 1.2.0-RC4
* Tue Mar  6 2012 suse@ammler.ch
- upstream update to 1.2.0-RC2
- spec overhaul for openSUSE Factory
* Mon Jan 16 2012 suse@ammler.ch
- upstream update 1.1.5
  * Fix: Make default timeouts for certain network states lower
    and configurable [CVE-2012-0049]
- disable dependency grfcodec
* Tue Dec  6 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Tue Dec  6 2011 suse@ammler.ch
- upstream update 1.1.4
  * various small bugfixes
* Sun Sep 18 2011 ammler@openttdcoop.org
- upstream update 1.1.3
  * Add: River graphics for the original base set
* Wed Aug 17 2011 ammler@openttdcoop.org
- upstream update 1.1.2
- no obs services anymore
* Thu Jun  2 2011 ammler@openttdcoop.org
- upstream update 1.1.1
* Fri Apr  1 2011 ammler@openttdcoop.org
- upstream update 1.1.0
  * Change newgrfs settings aren't allowed anymore on running
    game per default, needs scenario_developer to be set
  * Feature: XZ/LZMA2 savegame support. New default reduces
    savegame size by 10 to 30%% with slightly more CPU usage.
    (requires xz-devel)
  * Feature: Remote administration
  * Feature: a lot improvements with GUI
  * Feature: Customizable hotkeys
  * Sources for openttd.grf are pngs (requires grfcodec >= 5.1)
* Sun Nov 21 2010 ammler@openttdcoop.org
- upstream update 1.0.5
  * Fix: Reading (very) recently freed memory [CVE-2010-4168]
* Sun Oct 31 2010 ammler@openttdcoop.org
- upstream update 1.0.4
  * build openttd.grf from source
* Tue Aug 10 2010 ammler@openttdcoop.org
- upstream update 1.0.3
* Wed Jun 23 2010 Marcel Gmür <ammler@openttdcoop.org>
- upstream update 1.0.2
  * Feature: Translated desktop shortcut comments (r19884)
  * many minor Bugfixes
* Sat May  1 2010 Marcel Gmür <ammler@openttdcoop.org>
- upstream update 1.0.1
  * Fix: Leaking a file descriptor
  * Fix a lot small bugs, like minor desync issues on Mulitplayer
- no strip on make
* Thu Apr  1 2010 Marcel Gmür <ammler@openttdcoop.org>
- upstream update 1.0.0 (finally!)
  * completely independend game but still working also
    with ttd original gaphics, sounds and music
- Add: Recommends openmsx
- requires lzo2
* Fri Dec 18 2009 Marcel Gmür <ammler@openttdcoop.org> - 0.7.4
- support for differen branches
- easy support for dedicated branch
- let openttd build system make the dektop file
- split the package to data and gui
- disable requires
* Thu Oct  1 2009 Marcel Gmür <ammler@openttdcoop.org> - 0.7.3
- disable libicu for RHEL4
* Sat Sep 26 2009 Marcel Gmür <ammler@openttdcoop.org> - 0.7.2
- no subfolder games for datadir
- cleanup: no post and postun anymore
- Recommends: opengfx (for suse and mandriva)
- add SUSE support
* Mon Oct 20 2008 Benedikt Brüggemeier <skidd13@openttd.org>
- Added libicu dependency
* Tue Sep 23 2008 Benedikt Brüggemeier <skidd13@openttd.org>
- Merged both versions of the spec file
* Fri Aug 29 2008 Jonathan Coome <maedhros@openttd.org>
- Rewrite spec file from scratch.
* Sat Aug  2 2008 Benedikt Brüggemeier <skidd13@openttd.org>
- Updated spec file
* Thu Mar 27 2008 Denis Burlaka <burlaka@yandex.ru>
- Universal spec file
